import { IfLayout as Layout } from './components'
import IfLayoutConfigStore from './store'
import { inject } from 'vue'
import { StoreName } from './hooks';
export default class IfLayoutConfig {
    constructor(app, config) {
        this.app = app;
        this.config = config;
        this.initConfig()
    }
    initConfig() {
        const { store, routes, config } = this.config;
        // 注册Model
        store.registerModule(StoreName, IfLayoutConfigStore, { preserveState: false });
        this.setRoutes(routes);
        if(config) this.update(config);

        // State数据持久化
        // createPersistedState({
        //     key: '__routes_config__',
        //     paths: ['ifauth.routesConfig', 'ifauth.lastRoute']
        // })(store)
    }

    update(config) {
        const { store } = this.config;
        store.commit(StoreName + '/updateConfig', config)
    }

    // 设定路由 推荐使用ifAuth
    setRoutes(routes) {
        const { store } = this.config;
        routes && store.commit(StoreName + '/setRoutes', routes)
    }



    static install(app, config) {
        const $IfLayoutConfig = new IfLayoutConfig(app, config)
        app.provide('IfLayoutConfig', $IfLayoutConfig);
        // 全局注册
        app.component(Layout.__name, Layout);
    }
}
export const IfLayout = Layout

export function useLayoutConfig() {
    return inject('IfLayoutConfig')
}